import os, ctypes

def windowsCommand(command):
    buffer = ctypes.create_unicode_buffer(600);
    ctypes.windll.winmm.mciSendStringW(command, buffer, 559, 0);

class SimpleSound():
    def play(self, fileName):
        if (os.path.isfile(fileName)):
            windowsCommand("open " + fileName);
            windowsCommand("play " + fileName + " wait");
            windowsCommand("close " + fileName);
        else:
            return fileName + " could not be found.";


from setuptools import setup, find_packages

setup(name = "simpleSound", version = "1.0.0a", author = "nekumelon", author_email = "nekumelon@gmail.com", packages = find_packages(), description = "A very very very simple sound playing library for windows.", url = "https://github.com/nekumelon/simpleSound", license = "MIT", install_requires = ["ctypes", "os"]);